@@ -18,6 +18,7 @@ from .._impl import (
     module_GetDerivedSeriesRequest as GetDerivedSeriesRequest,
     module_GetDerivedSeriesResponse as GetDerivedSeriesResponse,
     module_GetModuleRequest as GetModuleRequest,
+    module_LatestVersionStrategy as LatestVersionStrategy,
     module_Module as Module,
     module_ModuleApplication as ModuleApplication,
     module_ModuleMetadata as ModuleMetadata,
@@ -26,9 +27,14 @@ from .._impl import (
     module_ModuleService as ModuleService,
     module_ModuleSummary as ModuleSummary,
     module_ModuleVariable as ModuleVariable,
+    module_ModuleVersion as ModuleVersion,
     module_ModuleVersionDefinition as ModuleVersionDefinition,
     module_ModuleVersionMetadata as ModuleVersionMetadata,
     module_ParameterName as ParameterName,
+    module_PinnedVersionStrategy as PinnedVersionStrategy,
+    module_RequestModuleNameRef as RequestModuleNameRef,
+    module_RequestModuleRef as RequestModuleRef,
+    module_RequestModuleRefVisitor as RequestModuleRefVisitor,
     module_SearchModuleApplicationsQuery as SearchModuleApplicationsQuery,
     module_SearchModuleApplicationsQueryVisitor as SearchModuleApplicationsQueryVisitor,
     module_SearchModuleApplicationsRequest as SearchModuleApplicationsRequest,
@@ -39,12 +45,13 @@ from .._impl import (
     module_SearchModulesResponse as SearchModulesResponse,
     module_SearchModulesSortField as SearchModulesSortField,
     module_SearchModulesSortOptions as SearchModulesSortOptions,
-    module_SemanticVersion as SemanticVersion,
     module_UpdateModuleApplicationRequest as UpdateModuleApplicationRequest,
     module_UpdateModuleApplicationResponse as UpdateModuleApplicationResponse,
     module_UpdateModuleRequest as UpdateModuleRequest,
     module_ValueType as ValueType,
     module_VariableName as VariableName,
+    module_VersionStrategy as VersionStrategy,
+    module_VersionStrategyVisitor as VersionStrategyVisitor,
 )
 
 __all__ = [
@@ -66,6 +73,7 @@ __all__ = [
     'GetDerivedSeriesRequest',
     'GetDerivedSeriesResponse',
     'GetModuleRequest',
+    'LatestVersionStrategy',
     'Module',
     'ModuleApplication',
     'ModuleMetadata',
@@ -73,9 +81,14 @@ __all__ = [
     'ModuleRef',
     'ModuleSummary',
     'ModuleVariable',
+    'ModuleVersion',
     'ModuleVersionDefinition',
     'ModuleVersionMetadata',
     'ParameterName',
+    'PinnedVersionStrategy',
+    'RequestModuleNameRef',
+    'RequestModuleRef',
+    'RequestModuleRefVisitor',
     'SearchModuleApplicationsQuery',
     'SearchModuleApplicationsQueryVisitor',
     'SearchModuleApplicationsRequest',
@@ -86,12 +99,13 @@ __all__ = [
     'SearchModulesResponse',
     'SearchModulesSortField',
     'SearchModulesSortOptions',
-    'SemanticVersion',
     'UpdateModuleApplicationRequest',
     'UpdateModuleApplicationResponse',
     'UpdateModuleRequest',
     'ValueType',
     'VariableName',
+    'VersionStrategy',
+    'VersionStrategyVisitor',
     'ModuleService',
 ]
 
