@@ -10,6 +10,7 @@ from .._impl import (
     scout_run_api_DataReviewAlertMetrics as DataReviewAlertMetrics,
     scout_run_api_DataReviewCheckMetrics as DataReviewCheckMetrics,
     scout_run_api_DataReviewMetrics as DataReviewMetrics,
+    scout_run_api_DataScopes as DataScopes,
     scout_run_api_DataSource as DataSource,
     scout_run_api_DataSourceSeriesTag as DataSourceSeriesTag,
     scout_run_api_DataSourceType as DataSourceType,
@@ -37,7 +38,11 @@ from .._impl import (
     scout_run_api_SearchRunsWithDataReviewMetricsResponse as SearchRunsWithDataReviewMetricsResponse,
     scout_run_api_SearchRunsWithDataReviewSummaryResponse as SearchRunsWithDataReviewSummaryResponse,
     scout_run_api_SortField as SortField,
+    scout_run_api_SortKey as SortKey,
+    scout_run_api_SortKeyVisitor as SortKeyVisitor,
     scout_run_api_SortOptions as SortOptions,
+    scout_run_api_SortProperty as SortProperty,
+    scout_run_api_TimeRangeFilter as TimeRangeFilter,
     scout_run_api_Unit as Unit,
     scout_run_api_UpdateAttachmentsRequest as UpdateAttachmentsRequest,
     scout_run_api_UpdateRunRequest as UpdateRunRequest,
@@ -45,3 +50,54 @@ from .._impl import (
     scout_run_api_WeakTimestampType as WeakTimestampType,
 )
 
+__all__ = [
+    'AllRunsPropertiesAndLabelsResponse',
+    'ChannelMetadata',
+    'CheckAlertStatesFilter',
+    'ConnectionRid',
+    'CreateOrUpdateRunRequest',
+    'CreateRunDataSource',
+    'CreateRunRequest',
+    'DataReviewAlertMetrics',
+    'DataReviewCheckMetrics',
+    'DataReviewMetrics',
+    'DataScopes',
+    'DataSource',
+    'DataSourceVisitor',
+    'DataSourceSeriesTag',
+    'DataSourceType',
+    'Duration',
+    'GetRunByIdRequest',
+    'GetRunsByAssetRequest',
+    'GetRunsByAssetResponse',
+    'Link',
+    'LogSetRid',
+    'RefNameAndType',
+    'Run',
+    'RunDataReviewEvaluationStatus',
+    'RunDataReviewSummary',
+    'RunDataSource',
+    'RunRid',
+    'RunWithDataReviewMetrics',
+    'RunWithDataReviewSummary',
+    'SearchQuery',
+    'SearchQueryVisitor',
+    'SearchRunChannelsRequest',
+    'SearchRunChannelsResponse',
+    'SearchRunsRequest',
+    'SearchRunsResponse',
+    'SearchRunsWithDataReviewMetricsResponse',
+    'SearchRunsWithDataReviewSummaryResponse',
+    'SortField',
+    'SortKey',
+    'SortKeyVisitor',
+    'SortOptions',
+    'SortProperty',
+    'TimeRangeFilter',
+    'Unit',
+    'UpdateAttachmentsRequest',
+    'UpdateRunRequest',
+    'UtcTimestamp',
+    'WeakTimestampType',
+]
+
